<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">
 
<!-- If we are making a copy then it is always editable -->
<xsl:variable name='gEditable'>
  <xsl:choose>
    <xsl:when test='/Form/@method="view"'>0</xsl:when>
    <xsl:when test='/Form/@method="copy"'>1</xsl:when>
    <xsl:otherwise><xsl:value-of select='/Form/function/@editable' /></xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="function"/>
</xsl:template>

<xsl:template match="function">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='../@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='function'>
    <xsl:choose>
      <xsl:when test='../@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='@function' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='revision'>
    <xsl:choose>
      <xsl:when test='../@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='@revision' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

<gjs:form
 title='Function'
 width='500'
 jsFile='vc575.js'
 onload='frmMain.func.focus();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='no'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>
  <xsl:if test='../@method!="copy"'>
    <xsl:attribute name='delete'><xsl:value-of select='/Form/@delete' /></xsl:attribute>
  </xsl:if>

  <gjs:information>
      <xsl:if test='../@method="copy"'>You are creating a copy of the definition of function '<xsl:value-of select='@function'/>'.&nbsp;</xsl:if>
    A function defines a method or operation that can be performed by the application.&nbsp; This is typically a JavaScript function in the 
    web UI, but many functions also have a server-side component.&nbsp; Access codes can be
    attached to any function to restrict who can execute that function.&nbsp; A function with no access restrictions
    can be executed by any authenticated user.&nbsp; An unauthenticated user can only access methods
    that are explicitly given an access code of ANONYMOUS.
  </gjs:information>

<div id='divFunction' class='visible' style='height: 200'>
  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='170'/>
    <gjs:column width='290'/>
  </gjs:columnWidths>

  <gjs:fields>

    <!-- function is a reserved word so use func -->
    <gjs:input
     id='func'
     accesskey='F'
     size='40'
     maxlength='200'
     value='{$function}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$gEditable="0"'>
        <xsl:attribute name='readonly'>1</xsl:attribute>
      </xsl:if>
      <label><u>F</u>unction</label>
      <hint>The name of the javascript function</hint>
    </gjs:input>

    <gjs:input
     id='description'
     accesskey='E'
     size='40'
     maxlength='200'
     value='{@description}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$gEditable="0"'>
        <xsl:attribute name='readonly'>1</xsl:attribute>
      </xsl:if>
      <label>D<u>e</u>scription</label>
      <hint>A brief description of the purpose of this function</hint>
    </gjs:input>

    <gjs:input
     id='serverSideMethod'
     accesskey='M'
     size='40'
     maxlength='200'
     value='{@serverSideMethod}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$gEditable="0"'>
        <xsl:attribute name='readonly'>1</xsl:attribute>
      </xsl:if>
      <label>Server-side <u>m</u>ethod</label>
      <hint>The entryref of the server-side method associated with this function if there is one.</hint>
    </gjs:input>

    <tr>
      <td height='16'></td>
    </tr>

    <gjs:input
     id='accessCodes'
     accesskey='A'
     size='40'
     maxlength='1000'
     value='{@accessCodes}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label><u>A</u>ccess rights</label>
     <hint>Enter a comma separated list of access rights.  Any user with any one of these rights will be permitted to execute this function.</hint>
    </gjs:input>

  </gjs:fields>

  <gjs:inputHidden id='revision' value='{$revision}'/>
  <gjs:inputHidden id='oldFunction' value='{$function}'/>

  </gjs:frame>
</div>
</gjs:form>
</xsl:template>

</xsl:stylesheet>
